@@ -51,6 +51,18 @@ class Transport:
         """Init constructor of Transport."""
         if debug:
             LOG.setLevel(logging.DEBUG)
+            # create console handler and set level to debug
+            ch = logging.StreamHandler()
+            ch.setLevel(logging.DEBUG)
+
+            # create formatter
+            formatter = logging.Formatter('%(name)s - %(levelname)s - %(message)s')
+
+            # add formatter to ch
+            ch.setFormatter(formatter)
+
+            # add ch to logger
+            LOG.addHandler(ch)
 
         self.interface: TransportType
 
